@@ -6,7 +6,6 @@ from collections.abc import Callable
 from datetime import datetime
 import logging
 import platform
-import time
 from typing import Any
 
 import async_timeout
@@ -16,21 +15,17 @@ from bleak.assigned_numbers import AdvertisementDataType
 from bleak.backends.bluezdbus.advertisement_monitor import OrPattern
 from bleak.backends.bluezdbus.scanner import BlueZScannerArgs
 from bleak.backends.device import BLEDevice
-from bleak.backends.scanner import AdvertisementData
+from bleak.backends.scanner import AdvertisementData, AdvertisementDataCallback
 from dbus_fast import InvalidMessageError
 
-from homeassistant.const import EVENT_HOMEASSISTANT_STOP
-from homeassistant.core import (
-    CALLBACK_TYPE,
-    Event,
-    HomeAssistant,
-    callback as hass_callback,
-)
+from homeassistant.core import CALLBACK_TYPE, HomeAssistant, callback as hass_callback
 from homeassistant.exceptions import HomeAssistantError
 from homeassistant.helpers.event import async_track_time_interval
+from homeassistant.util.dt import monotonic_time_coarse
 from homeassistant.util.package import is_docker_env
 
 from .const import (
+    DEFAULT_ADDRESS,
     SCANNER_WATCHDOG_INTERVAL,
     SCANNER_WATCHDOG_TIMEOUT,
     SOURCE_LOCAL,
@@ -40,7 +35,7 @@ from .models import BaseHaScanner, BluetoothScanningMode, BluetoothServiceInfoBl
 from .util import adapter_human_name, async_reset_adapter
 
 OriginalBleakScanner = bleak.BleakScanner
-MONOTONIC_TIME = time.monotonic
+MONOTONIC_TIME = monotonic_time_coarse
 
 # or_patterns is a workaround for the fact that passive scanning
 # needs at least one matcher to be set. The below matcher
@@ -54,8 +49,6 @@ PASSIVE_SCANNER_ARGS = BlueZScannerArgs(
 _LOGGER = logging.getLogger(__name__)
 
 
-MONOTONIC_TIME = time.monotonic
-
 # If the adapter is in a stuck state the following errors are raised:
 NEED_RESET_ERRORS = [
     "org.bluez.Error.Failed",
@@ -90,11 +83,14 @@ class ScannerStartError(HomeAssistantError):
 
 
 def create_bleak_scanner(
-    scanning_mode: BluetoothScanningMode, adapter: str | None
+    detection_callback: AdvertisementDataCallback,
+    scanning_mode: BluetoothScanningMode,
+    adapter: str | None,
 ) -> bleak.BleakScanner:
     """Create a Bleak scanner."""
     scanner_kwargs: dict[str, Any] = {
-        "scanning_mode": SCANNING_MODE_TO_BLEAK[scanning_mode]
+        "detection_callback": detection_callback,
+        "scanning_mode": SCANNING_MODE_TO_BLEAK[scanning_mode],
     }
     if platform.system() == "Linux":
         # Only Linux supports multiple adapters
@@ -121,31 +117,46 @@ class HaScanner(BaseHaScanner):
     over ethernet, usb over ethernet, etc.
     """
 
+    scanner: bleak.BleakScanner
+
     def __init__(
         self,
         hass: HomeAssistant,
-        scanner: bleak.BleakScanner,
+        mode: BluetoothScanningMode,
         adapter: str,
         address: str,
     ) -> None:
         """Init bluetooth discovery."""
-        self.hass = hass
-        self.scanner = scanner
+        source = address if address != DEFAULT_ADDRESS else adapter or SOURCE_LOCAL
+        super().__init__(hass, source)
+        self.mode = mode
         self.adapter = adapter
         self._start_stop_lock = asyncio.Lock()
-        self._cancel_stop: CALLBACK_TYPE | None = None
         self._cancel_watchdog: CALLBACK_TYPE | None = None
         self._last_detection = 0.0
         self._start_time = 0.0
         self._callbacks: list[Callable[[BluetoothServiceInfoBleak], None]] = []
         self.name = adapter_human_name(adapter, address)
-        self.source = self.adapter or SOURCE_LOCAL
 
     @property
     def discovered_devices(self) -> list[BLEDevice]:
         """Return a list of discovered devices."""
         return self.scanner.discovered_devices
 
+    @property
+    def discovered_devices_and_advertisement_data(
+        self,
+    ) -> dict[str, tuple[BLEDevice, AdvertisementData]]:
+        """Return a list of discovered devices and advertisement data."""
+        return self.scanner.discovered_devices_and_advertisement_data
+
+    @hass_callback
+    def async_setup(self) -> None:
+        """Set up the scanner."""
+        self.scanner = create_bleak_scanner(
+            self._async_detection_callback, self.mode, self.adapter
+        )
+
     async def async_diagnostics(self) -> dict[str, Any]:
         """Return diagnostic information about the scanner."""
         base_diag = await super().async_diagnostics()
@@ -213,8 +224,6 @@ class HaScanner(BaseHaScanner):
 
     async def async_start(self) -> None:
         """Start bluetooth scanner."""
-        self.scanner.register_detection_callback(self._async_detection_callback)
-
         async with self._start_stop_lock:
             await self._async_start()
 
@@ -318,9 +327,6 @@ class HaScanner(BaseHaScanner):
             break
 
         self._async_setup_scanner_watchdog()
-        self._cancel_stop = self.hass.bus.async_listen_once(
-            EVENT_HOMEASSISTANT_STOP, self._async_hass_stopping
-        )
 
     @hass_callback
     def _async_setup_scanner_watchdog(self) -> None:
@@ -341,6 +347,12 @@ class HaScanner(BaseHaScanner):
         )
         if time_since_last_detection < SCANNER_WATCHDOG_TIMEOUT:
             return
+        if self._start_stop_lock.locked():
+            _LOGGER.debug(
+                "%s: Scanner is already restarting, deferring restart",
+                self.name,
+            )
+            return
         _LOGGER.info(
             "%s: Bluetooth scanner has gone quiet for %ss, restarting",
             self.name,
@@ -368,11 +380,6 @@ class HaScanner(BaseHaScanner):
                     exc_info=True,
                 )
 
-    async def _async_hass_stopping(self, event: Event) -> None:
-        """Stop the Bluetooth integration at shutdown."""
-        self._cancel_stop = None
-        await self.async_stop()
-
     async def _async_reset_adapter(self) -> None:
         """Reset the adapter."""
         # There is currently nothing the user can do to fix this
@@ -384,21 +391,14 @@ class HaScanner(BaseHaScanner):
 
     async def async_stop(self) -> None:
         """Stop bluetooth scanner."""
-        async with self._start_stop_lock:
-            await self._async_stop()
-
-    async def _async_stop(self) -> None:
-        """Cancel watchdog and bluetooth discovery under the lock."""
         if self._cancel_watchdog:
             self._cancel_watchdog()
             self._cancel_watchdog = None
-        await self._async_stop_scanner()
+        async with self._start_stop_lock:
+            await self._async_stop_scanner()
 
     async def _async_stop_scanner(self) -> None:
         """Stop bluetooth discovery under the lock."""
-        if self._cancel_stop:
-            self._cancel_stop()
-            self._cancel_stop = None
         _LOGGER.debug("%s: Stopping bluetooth discovery", self.name)
         try:
             await self.scanner.stop()  # type: ignore[no-untyped-call]
