@@ -5,16 +5,14 @@ import asyncio
 import logging
 
 from homeassistant.components.humidifier import (
+    ATTR_HUMIDITY,
+    MODE_AWAY,
+    MODE_NORMAL,
     PLATFORM_SCHEMA,
     HumidifierDeviceClass,
     HumidifierEntity,
     HumidifierEntityFeature,
 )
-from homeassistant.components.humidifier.const import (
-    ATTR_HUMIDITY,
-    MODE_AWAY,
-    MODE_NORMAL,
-)
 from homeassistant.const import (
     ATTR_ENTITY_ID,
     ATTR_MODE,
@@ -112,6 +110,8 @@ async def async_setup_platform(
 class GenericHygrostat(HumidifierEntity, RestoreEntity):
     """Representation of a Generic Hygrostat device."""
 
+    _attr_should_poll = False
+
     def __init__(
         self,
         name,
@@ -218,11 +218,6 @@ class GenericHygrostat(HumidifierEntity, RestoreEntity):
             return {ATTR_SAVED_HUMIDITY: self._saved_target_humidity}
         return None
 
-    @property
-    def should_poll(self):
-        """Return the polling state."""
-        return False
-
     @property
     def name(self):
         """Return the name of the hygrostat."""
@@ -287,7 +282,7 @@ class GenericHygrostat(HumidifierEntity, RestoreEntity):
             return
 
         self._target_humidity = humidity
-        await self._async_operate(force=True)
+        await self._async_operate()
         await self.async_update_ha_state()
 
     @property
