@@ -7,9 +7,11 @@ from typing import Any
 from pyhap.const import CATEGORY_SENSOR
 
 from homeassistant.core import CALLBACK_TYPE, Context
+from homeassistant.helpers import entity_registry
 from homeassistant.helpers.trigger import async_initialize_triggers
 
 from .accessories import TYPES, HomeAccessory
+from .aidmanager import get_system_unique_id
 from .const import (
     CHAR_NAME,
     CHAR_PROGRAMMABLE_SWITCH_EVENT,
@@ -18,6 +20,7 @@ from .const import (
     SERV_SERVICE_LABEL,
     SERV_STATELESS_PROGRAMMABLE_SWITCH,
 )
+from .util import cleanup_name_for_homekit
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -39,15 +42,26 @@ class DeviceTriggerAccessory(HomeAccessory):
         self._remove_triggers: CALLBACK_TYPE | None = None
         self.triggers = []
         assert device_triggers is not None
+        ent_reg = entity_registry.async_get(self.hass)
         for idx, trigger in enumerate(device_triggers):
-            type_ = trigger["type"]
-            subtype = trigger.get("subtype")
-            trigger_name = (
-                f"{type_.title()} {subtype.title()}" if subtype else type_.title()
-            )
+            type_: str = trigger["type"]
+            subtype: str | None = trigger.get("subtype")
+            unique_id = f'{type_}-{subtype or ""}'
+            if (entity_id := trigger.get("entity_id")) and (
+                entry := ent_reg.async_get(entity_id)
+            ):
+                unique_id += f"-entity_unique_id:{get_system_unique_id(entry)}"
+            trigger_name_parts = []
+            if entity_id and (state := self.hass.states.get(entity_id)):
+                trigger_name_parts.append(state.name)
+            trigger_name_parts.append(type_.replace("_", " ").title())
+            if subtype:
+                trigger_name_parts.append(subtype.replace("_", " ").title())
+            trigger_name = cleanup_name_for_homekit(" ".join(trigger_name_parts))
             serv_stateless_switch = self.add_preload_service(
                 SERV_STATELESS_PROGRAMMABLE_SWITCH,
                 [CHAR_NAME, CHAR_SERVICE_LABEL_INDEX],
+                unique_id=unique_id,
             )
             self.triggers.append(
                 serv_stateless_switch.configure_char(
@@ -60,7 +74,9 @@ class DeviceTriggerAccessory(HomeAccessory):
             serv_stateless_switch.configure_char(
                 CHAR_SERVICE_LABEL_INDEX, value=idx + 1
             )
-            serv_service_label = self.add_preload_service(SERV_SERVICE_LABEL)
+            serv_service_label = self.add_preload_service(
+                SERV_SERVICE_LABEL, unique_id=unique_id
+            )
             serv_service_label.configure_char(CHAR_SERVICE_LABEL_NAMESPACE, value=1)
             serv_stateless_switch.add_linked_service(serv_service_label)
 
