@@ -6,6 +6,7 @@ from datetime import timedelta
 import hashlib
 import logging
 import os
+from typing import Any
 
 import mpd
 from mpd.asyncio import MPDClient
@@ -14,28 +15,15 @@ import voluptuous as vol
 from homeassistant.components import media_source
 from homeassistant.components.media_player import (
     PLATFORM_SCHEMA,
+    BrowseMedia,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
-)
-from homeassistant.components.media_player.browse_media import (
+    MediaPlayerState,
+    MediaType,
+    RepeatMode,
     async_process_play_media_url,
 )
-from homeassistant.components.media_player.const import (
-    MEDIA_TYPE_MUSIC,
-    MEDIA_TYPE_PLAYLIST,
-    REPEAT_MODE_ALL,
-    REPEAT_MODE_OFF,
-    REPEAT_MODE_ONE,
-)
-from homeassistant.const import (
-    CONF_HOST,
-    CONF_NAME,
-    CONF_PASSWORD,
-    CONF_PORT,
-    STATE_OFF,
-    STATE_PAUSED,
-    STATE_PLAYING,
-)
+from homeassistant.const import CONF_HOST, CONF_NAME, CONF_PASSWORD, CONF_PORT
 from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -95,6 +83,8 @@ async def async_setup_platform(
 class MpdDevice(MediaPlayerEntity):
     """Representation of a MPD server."""
 
+    _attr_media_content_type = MediaType.MUSIC
+
     # pylint: disable=no-member
     def __init__(self, server, port, password, name):
         """Initialize the MPD device."""
@@ -164,7 +154,7 @@ class MpdDevice(MediaPlayerEntity):
         """Return true if MPD is available and connected."""
         return self._is_connected
 
-    async def async_update(self):
+    async def async_update(self) -> None:
         """Get the latest data and update the state."""
         try:
             if not self._is_connected:
@@ -183,18 +173,18 @@ class MpdDevice(MediaPlayerEntity):
         return self._name
 
     @property
-    def state(self):
+    def state(self) -> MediaPlayerState:
         """Return the media state."""
         if self._status is None:
-            return STATE_OFF
+            return MediaPlayerState.OFF
         if self._status["state"] == "play":
-            return STATE_PLAYING
+            return MediaPlayerState.PLAYING
         if self._status["state"] == "pause":
-            return STATE_PAUSED
+            return MediaPlayerState.PAUSED
         if self._status["state"] == "stop":
-            return STATE_OFF
+            return MediaPlayerState.OFF
 
-        return STATE_OFF
+        return MediaPlayerState.OFF
 
     @property
     def is_volume_muted(self):
@@ -206,11 +196,6 @@ class MpdDevice(MediaPlayerEntity):
         """Return the content ID of current playing media."""
         return self._currentsong.get("file")
 
-    @property
-    def media_content_type(self):
-        """Return the content type of current playing media."""
-        return MEDIA_TYPE_MUSIC
-
     @property
     def media_duration(self):
         """Return the duration of current playing media in seconds."""
@@ -273,7 +258,7 @@ class MpdDevice(MediaPlayerEntity):
         """Hash value for media image."""
         return self._media_image_hash
 
-    async def async_get_media_image(self):
+    async def async_get_media_image(self) -> tuple[bytes | None, str | None]:
         """Fetch media image of current playing track."""
         if not (file := self._currentsong.get("file")):
             return None, None
@@ -380,12 +365,12 @@ class MpdDevice(MediaPlayerEntity):
         """Return the list of available input sources."""
         return self._playlists
 
-    async def async_select_source(self, source):
+    async def async_select_source(self, source: str) -> None:
         """Choose a different available playlist and play it."""
-        await self.async_play_media(MEDIA_TYPE_PLAYLIST, source)
+        await self.async_play_media(MediaType.PLAYLIST, source)
 
     @Throttle(PLAYLIST_UPDATE_INTERVAL)
-    async def _update_playlists(self, **kwargs):
+    async def _update_playlists(self, **kwargs: Any) -> None:
         """Update available MPD playlists."""
         try:
             self._playlists = []
@@ -395,12 +380,12 @@ class MpdDevice(MediaPlayerEntity):
             self._playlists = None
             _LOGGER.warning("Playlists could not be updated: %s:", error)
 
-    async def async_set_volume_level(self, volume):
+    async def async_set_volume_level(self, volume: float) -> None:
         """Set volume of media player."""
         if "volume" in self._status:
             await self._client.setvol(int(volume * 100))
 
-    async def async_volume_up(self):
+    async def async_volume_up(self) -> None:
         """Service to send the MPD the command for volume up."""
         if "volume" in self._status:
             current_volume = int(self._status["volume"])
@@ -408,7 +393,7 @@ class MpdDevice(MediaPlayerEntity):
             if current_volume <= 100:
                 self._client.setvol(current_volume + 5)
 
-    async def async_volume_down(self):
+    async def async_volume_down(self) -> None:
         """Service to send the MPD the command for volume down."""
         if "volume" in self._status:
             current_volume = int(self._status["volume"])
@@ -416,30 +401,30 @@ class MpdDevice(MediaPlayerEntity):
             if current_volume >= 0:
                 await self._client.setvol(current_volume - 5)
 
-    async def async_media_play(self):
+    async def async_media_play(self) -> None:
         """Service to send the MPD the command for play/pause."""
         if self._status["state"] == "pause":
             await self._client.pause(0)
         else:
             await self._client.play()
 
-    async def async_media_pause(self):
+    async def async_media_pause(self) -> None:
         """Service to send the MPD the command for play/pause."""
         await self._client.pause(1)
 
-    async def async_media_stop(self):
+    async def async_media_stop(self) -> None:
         """Service to send the MPD the command for stop."""
         await self._client.stop()
 
-    async def async_media_next_track(self):
+    async def async_media_next_track(self) -> None:
         """Service to send the MPD the command for next track."""
         await self._client.next()
 
-    async def async_media_previous_track(self):
+    async def async_media_previous_track(self) -> None:
         """Service to send the MPD the command for previous track."""
         await self._client.previous()
 
-    async def async_mute_volume(self, mute):
+    async def async_mute_volume(self, mute: bool) -> None:
         """Mute. Emulated with set_volume_level."""
         if "volume" in self._status:
             if mute:
@@ -449,16 +434,18 @@ class MpdDevice(MediaPlayerEntity):
                 await self.async_set_volume_level(self._muted_volume)
             self._muted = mute
 
-    async def async_play_media(self, media_type, media_id, **kwargs):
+    async def async_play_media(
+        self, media_type: str, media_id: str, **kwargs: Any
+    ) -> None:
         """Send the media player the command for playing a playlist."""
         if media_source.is_media_source_id(media_id):
-            media_type = MEDIA_TYPE_MUSIC
+            media_type = MediaType.MUSIC
             play_item = await media_source.async_resolve_media(
                 self.hass, media_id, self.entity_id
             )
             media_id = async_process_play_media_url(self.hass, play_item.url)
 
-        if media_type == MEDIA_TYPE_PLAYLIST:
+        if media_type == MediaType.PLAYLIST:
             _LOGGER.debug("Playing playlist: %s", media_id)
             if media_id in self._playlists:
                 self._currentplaylist = media_id
@@ -475,22 +462,22 @@ class MpdDevice(MediaPlayerEntity):
             await self._client.play()
 
     @property
-    def repeat(self):
+    def repeat(self) -> RepeatMode:
         """Return current repeat mode."""
         if self._status["repeat"] == "1":
             if self._status["single"] == "1":
-                return REPEAT_MODE_ONE
-            return REPEAT_MODE_ALL
-        return REPEAT_MODE_OFF
+                return RepeatMode.ONE
+            return RepeatMode.ALL
+        return RepeatMode.OFF
 
-    async def async_set_repeat(self, repeat):
+    async def async_set_repeat(self, repeat: RepeatMode) -> None:
         """Set repeat mode."""
-        if repeat == REPEAT_MODE_OFF:
+        if repeat == RepeatMode.OFF:
             await self._client.repeat(0)
             await self._client.single(0)
         else:
             await self._client.repeat(1)
-            if repeat == REPEAT_MODE_ONE:
+            if repeat == RepeatMode.ONE:
                 await self._client.single(1)
             else:
                 await self._client.single(0)
@@ -500,28 +487,30 @@ class MpdDevice(MediaPlayerEntity):
         """Boolean if shuffle is enabled."""
         return bool(int(self._status["random"]))
 
-    async def async_set_shuffle(self, shuffle):
+    async def async_set_shuffle(self, shuffle: bool) -> None:
         """Enable/disable shuffle mode."""
         await self._client.random(int(shuffle))
 
-    async def async_turn_off(self):
+    async def async_turn_off(self) -> None:
         """Service to send the MPD the command to stop playing."""
         await self._client.stop()
 
-    async def async_turn_on(self):
+    async def async_turn_on(self) -> None:
         """Service to send the MPD the command to start playing."""
         await self._client.play()
         await self._update_playlists(no_throttle=True)
 
-    async def async_clear_playlist(self):
+    async def async_clear_playlist(self) -> None:
         """Clear players playlist."""
         await self._client.clear()
 
-    async def async_media_seek(self, position):
+    async def async_media_seek(self, position: float) -> None:
         """Send seek command."""
         await self._client.seekcur(position)
 
-    async def async_browse_media(self, media_content_type=None, media_content_id=None):
+    async def async_browse_media(
+        self, media_content_type: str | None = None, media_content_id: str | None = None
+    ) -> BrowseMedia:
         """Implement the websocket media browsing helper."""
         return await media_source.async_browse_media(
             self.hass,
