@@ -17,14 +17,14 @@ from sqlalchemy.sql.expression import literal
 from sqlalchemy.sql.lambdas import StatementLambdaElement
 from sqlalchemy.sql.selectable import Subquery
 
-from homeassistant.components import recorder
-from homeassistant.components.websocket_api.const import (
+from homeassistant.components.websocket_api import (
     COMPRESSED_STATE_LAST_UPDATED,
     COMPRESSED_STATE_STATE,
 )
 from homeassistant.core import HomeAssistant, State, split_entity_id
 import homeassistant.util.dt as dt_util
 
+from .. import recorder
 from .db_schema import RecorderRuns, StateAttributes, States
 from .filters import Filters
 from .models import (
@@ -36,8 +36,6 @@ from .models import (
 )
 from .util import execute_stmt_lambda_element, session_scope
 
-# mypy: allow-untyped-defs, no-check-untyped-defs
-
 _LOGGER = logging.getLogger(__name__)
 
 STATE_KEY = "state"
