@@ -1,42 +1,31 @@
 """Shelly entity helper."""
 from __future__ import annotations
 
-import asyncio
 from collections.abc import Callable, Mapping
 from dataclasses import dataclass
 from typing import Any, cast
 
 from aioshelly.block_device import Block
-import async_timeout
+from aioshelly.exceptions import DeviceConnectionError, InvalidAuthError, RpcCallError
 
 from homeassistant.config_entries import ConfigEntry
+from homeassistant.const import ATTR_UNIT_OF_MEASUREMENT
 from homeassistant.core import HomeAssistant, callback
-from homeassistant.helpers import (
-    device_registry,
-    entity,
-    entity_registry,
-    update_coordinator,
-)
+from homeassistant.exceptions import HomeAssistantError
+from homeassistant.helpers import device_registry, entity, entity_registry
 from homeassistant.helpers.entity import DeviceInfo, EntityDescription
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
+from homeassistant.helpers.entity_registry import RegistryEntry
 from homeassistant.helpers.restore_state import RestoreEntity
 from homeassistant.helpers.typing import StateType
+from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
-from . import (
-    BlockDeviceWrapper,
-    RpcDeviceWrapper,
-    RpcPollingWrapper,
-    ShellyDeviceRestWrapper,
-)
-from .const import (
-    AIOSHELLY_DEVICE_TIMEOUT_SEC,
-    BLOCK,
-    DATA_CONFIG_ENTRY,
-    DOMAIN,
-    LOGGER,
-    REST,
-    RPC,
-    RPC_POLL,
+from .const import CONF_SLEEP_PERIOD, LOGGER
+from .coordinator import (
+    ShellyBlockCoordinator,
+    ShellyRpcCoordinator,
+    ShellyRpcPollingCoordinator,
+    get_entry_data,
 )
 from .utils import (
     async_remove_shelly_entity,
@@ -53,25 +42,21 @@ def async_setup_entry_attribute_entities(
     async_add_entities: AddEntitiesCallback,
     sensors: Mapping[tuple[str, str], BlockEntityDescription],
     sensor_class: Callable,
-    description_class: Callable[
-        [entity_registry.RegistryEntry], BlockEntityDescription
-    ],
+    description_class: Callable[[RegistryEntry], BlockEntityDescription],
 ) -> None:
     """Set up entities for attributes."""
-    wrapper: BlockDeviceWrapper = hass.data[DOMAIN][DATA_CONFIG_ENTRY][
-        config_entry.entry_id
-    ][BLOCK]
-
-    if wrapper.device.initialized:
+    coordinator = get_entry_data(hass)[config_entry.entry_id].block
+    assert coordinator
+    if coordinator.device.initialized:
         async_setup_block_attribute_entities(
-            hass, async_add_entities, wrapper, sensors, sensor_class
+            hass, async_add_entities, coordinator, sensors, sensor_class
         )
     else:
         async_restore_block_attribute_entities(
             hass,
             config_entry,
             async_add_entities,
-            wrapper,
+            coordinator,
             sensors,
             sensor_class,
             description_class,
@@ -82,16 +67,16 @@ def async_setup_entry_attribute_entities(
 def async_setup_block_attribute_entities(
     hass: HomeAssistant,
     async_add_entities: AddEntitiesCallback,
-    wrapper: BlockDeviceWrapper,
+    coordinator: ShellyBlockCoordinator,
     sensors: Mapping[tuple[str, str], BlockEntityDescription],
     sensor_class: Callable,
 ) -> None:
     """Set up entities for block attributes."""
     blocks = []
 
-    assert wrapper.device.blocks
+    assert coordinator.device.blocks
 
-    for block in wrapper.device.blocks:
+    for block in coordinator.device.blocks:
         for sensor_id in block.sensor_ids:
             description = sensors.get((block.type, sensor_id))
             if description is None:
@@ -103,10 +88,10 @@ def async_setup_block_attribute_entities(
 
             # Filter and remove entities that according to settings should not create an entity
             if description.removal_condition and description.removal_condition(
-                wrapper.device.settings, block
+                coordinator.device.settings, block
             ):
                 domain = sensor_class.__module__.split(".")[-1]
-                unique_id = f"{wrapper.mac}-{block.description}-{sensor_id}"
+                unique_id = f"{coordinator.mac}-{block.description}-{sensor_id}"
                 async_remove_shelly_entity(hass, domain, unique_id)
             else:
                 blocks.append((block, sensor_id, description))
@@ -116,7 +101,7 @@ def async_setup_block_attribute_entities(
 
     async_add_entities(
         [
-            sensor_class(wrapper, block, sensor_id, description)
+            sensor_class(coordinator, block, sensor_id, description)
             for block, sensor_id, description in blocks
         ]
     )
@@ -127,12 +112,10 @@ def async_restore_block_attribute_entities(
     hass: HomeAssistant,
     config_entry: ConfigEntry,
     async_add_entities: AddEntitiesCallback,
-    wrapper: BlockDeviceWrapper,
+    coordinator: ShellyBlockCoordinator,
     sensors: Mapping[tuple[str, str], BlockEntityDescription],
     sensor_class: Callable,
-    description_class: Callable[
-        [entity_registry.RegistryEntry], BlockEntityDescription
-    ],
+    description_class: Callable[[RegistryEntry], BlockEntityDescription],
 ) -> None:
     """Restore block attributes entities."""
     entities = []
@@ -152,7 +135,7 @@ def async_restore_block_attribute_entities(
         description = description_class(entry)
 
         entities.append(
-            sensor_class(wrapper, None, attribute, description, entry, sensors)
+            sensor_class(coordinator, None, attribute, description, entry, sensors)
         )
 
     if not entities:
@@ -169,41 +152,105 @@ def async_setup_entry_rpc(
     sensors: Mapping[str, RpcEntityDescription],
     sensor_class: Callable,
 ) -> None:
-    """Set up entities for REST sensors."""
-    wrapper: RpcDeviceWrapper = hass.data[DOMAIN][DATA_CONFIG_ENTRY][
-        config_entry.entry_id
-    ][RPC]
+    """Set up entities for RPC sensors."""
+    coordinator = get_entry_data(hass)[config_entry.entry_id].rpc
+    assert coordinator
 
-    polling_wrapper: RpcPollingWrapper = hass.data[DOMAIN][DATA_CONFIG_ENTRY][
-        config_entry.entry_id
-    ][RPC_POLL]
+    if coordinator.device.initialized:
+        async_setup_rpc_attribute_entities(
+            hass, config_entry, async_add_entities, sensors, sensor_class
+        )
+    else:
+        async_restore_rpc_attribute_entities(
+            hass, config_entry, async_add_entities, coordinator, sensors, sensor_class
+        )
+
+
+@callback
+def async_setup_rpc_attribute_entities(
+    hass: HomeAssistant,
+    config_entry: ConfigEntry,
+    async_add_entities: AddEntitiesCallback,
+    sensors: Mapping[str, RpcEntityDescription],
+    sensor_class: Callable,
+) -> None:
+    """Set up entities for RPC attributes."""
+    coordinator = get_entry_data(hass)[config_entry.entry_id].rpc
+    assert coordinator
+
+    if not (sleep_period := config_entry.data[CONF_SLEEP_PERIOD]):
+        polling_coordinator = get_entry_data(hass)[config_entry.entry_id].rpc_poll
+        assert polling_coordinator
 
     entities = []
     for sensor_id in sensors:
         description = sensors[sensor_id]
-        key_instances = get_rpc_key_instances(wrapper.device.status, description.key)
+        key_instances = get_rpc_key_instances(
+            coordinator.device.status, description.key
+        )
 
         for key in key_instances:
             # Filter non-existing sensors
-            if description.sub_key not in wrapper.device.status[
+            if description.sub_key not in coordinator.device.status[
                 key
-            ] and not description.supported(wrapper.device.status[key]):
+            ] and not description.supported(coordinator.device.status[key]):
                 continue
 
             # Filter and remove entities that according to settings/status should not create an entity
             if description.removal_condition and description.removal_condition(
-                wrapper.device.config, wrapper.device.status, key
+                coordinator.device.config, coordinator.device.status, key
             ):
                 domain = sensor_class.__module__.split(".")[-1]
-                unique_id = f"{wrapper.mac}-{key}-{sensor_id}"
+                unique_id = f"{coordinator.mac}-{key}-{sensor_id}"
                 async_remove_shelly_entity(hass, domain, unique_id)
             else:
-                if description.use_polling_wrapper:
-                    entities.append(
-                        sensor_class(polling_wrapper, key, sensor_id, description)
-                    )
+                if description.use_polling_coordinator:
+                    if not sleep_period:
+                        entities.append(
+                            sensor_class(
+                                polling_coordinator, key, sensor_id, description
+                            )
+                        )
                 else:
-                    entities.append(sensor_class(wrapper, key, sensor_id, description))
+                    entities.append(
+                        sensor_class(coordinator, key, sensor_id, description)
+                    )
+    if not entities:
+        return
+
+    async_add_entities(entities)
+
+
+@callback
+def async_restore_rpc_attribute_entities(
+    hass: HomeAssistant,
+    config_entry: ConfigEntry,
+    async_add_entities: AddEntitiesCallback,
+    coordinator: ShellyRpcCoordinator,
+    sensors: Mapping[str, RpcEntityDescription],
+    sensor_class: Callable,
+) -> None:
+    """Restore block attributes entities."""
+    entities = []
+
+    ent_reg = entity_registry.async_get(hass)
+    entries = entity_registry.async_entries_for_config_entry(
+        ent_reg, config_entry.entry_id
+    )
+
+    domain = sensor_class.__module__.split(".")[-1]
+
+    for entry in entries:
+        if entry.domain != domain:
+            continue
+
+        key = entry.unique_id.split("-")[-2]
+        attribute = entry.unique_id.split("-")[-1]
+
+        if description := sensors.get(attribute):
+            entities.append(
+                sensor_class(coordinator, key, attribute, description, entry)
+            )
 
     if not entities:
         return
@@ -220,15 +267,13 @@ def async_setup_entry_rest(
     sensor_class: Callable,
 ) -> None:
     """Set up entities for REST sensors."""
-    wrapper: ShellyDeviceRestWrapper = hass.data[DOMAIN][DATA_CONFIG_ENTRY][
-        config_entry.entry_id
-    ][REST]
-
+    coordinator = get_entry_data(hass)[config_entry.entry_id].rest
+    assert coordinator
     entities = []
     for sensor_id in sensors:
         description = sensors.get(sensor_id)
 
-        if not wrapper.device.settings.get("sleep_mode"):
+        if not coordinator.device.settings.get("sleep_mode"):
             entities.append((sensor_id, description))
 
     if not entities:
@@ -236,7 +281,7 @@ def async_setup_entry_rest(
 
     async_add_entities(
         [
-            sensor_class(wrapper, sensor_id, description)
+            sensor_class(coordinator, sensor_id, description)
             for sensor_id, description in entities
         ]
     )
@@ -270,7 +315,7 @@ class RpcEntityDescription(EntityDescription, RpcEntityRequiredKeysMixin):
     available: Callable[[dict], bool] | None = None
     removal_condition: Callable[[dict, dict, str], bool] | None = None
     extra_state_attributes: Callable[[dict, dict], dict | None] | None = None
-    use_polling_wrapper: bool = False
+    use_polling_coordinator: bool = False
     supported: Callable = lambda _: False
 
 
@@ -282,32 +327,32 @@ class RestEntityDescription(EntityDescription):
     extra_state_attributes: Callable[[dict], dict | None] | None = None
 
 
-class ShellyBlockEntity(entity.Entity):
+class ShellyBlockEntity(CoordinatorEntity[ShellyBlockCoordinator]):
     """Helper class to represent a block entity."""
 
-    def __init__(self, wrapper: BlockDeviceWrapper, block: Block) -> None:
+    def __init__(self, coordinator: ShellyBlockCoordinator, block: Block) -> None:
         """Initialize Shelly entity."""
-        self.wrapper = wrapper
+        super().__init__(coordinator)
         self.block = block
-        self._attr_name = get_block_entity_name(wrapper.device, block)
+        self._attr_name = get_block_entity_name(coordinator.device, block)
         self._attr_should_poll = False
         self._attr_device_info = DeviceInfo(
-            connections={(device_registry.CONNECTION_NETWORK_MAC, wrapper.mac)}
+            connections={(device_registry.CONNECTION_NETWORK_MAC, coordinator.mac)}
         )
-        self._attr_unique_id = f"{wrapper.mac}-{block.description}"
+        self._attr_unique_id = f"{coordinator.mac}-{block.description}"
 
     @property
     def available(self) -> bool:
         """Available."""
-        return self.wrapper.last_update_success
+        return self.coordinator.last_update_success
 
     async def async_added_to_hass(self) -> None:
         """When entity is added to HASS."""
-        self.async_on_remove(self.wrapper.async_add_listener(self._update_callback))
+        self.async_on_remove(self.coordinator.async_add_listener(self._update_callback))
 
     async def async_update(self) -> None:
         """Update entity with latest info."""
-        await self.wrapper.async_request_refresh()
+        await self.coordinator.async_request_refresh()
 
     @callback
     def _update_callback(self) -> None:
@@ -318,17 +363,14 @@ class ShellyBlockEntity(entity.Entity):
         """Set block state (HTTP request)."""
         LOGGER.debug("Setting state for entity %s, state: %s", self.name, kwargs)
         try:
-            async with async_timeout.timeout(AIOSHELLY_DEVICE_TIMEOUT_SEC):
-                return await self.block.set_state(**kwargs)
-        except (asyncio.TimeoutError, OSError) as err:
-            LOGGER.error(
-                "Setting state for entity %s failed, state: %s, error: %s",
-                self.name,
-                kwargs,
-                repr(err),
-            )
-            self.wrapper.last_update_success = False
-            return None
+            return await self.block.set_state(**kwargs)
+        except DeviceConnectionError as err:
+            self.coordinator.last_update_success = False
+            raise HomeAssistantError(
+                f"Setting state for entity {self.name} failed, state: {kwargs}, error: {repr(err)}"
+            ) from err
+        except InvalidAuthError:
+            self.coordinator.entry.async_start_reauth(self.hass)
 
 
 class ShellyRpcEntity(entity.Entity):
@@ -336,36 +378,36 @@ class ShellyRpcEntity(entity.Entity):
 
     def __init__(
         self,
-        wrapper: RpcDeviceWrapper | RpcPollingWrapper,
+        coordinator: ShellyRpcCoordinator | ShellyRpcPollingCoordinator,
         key: str,
     ) -> None:
         """Initialize Shelly entity."""
-        self.wrapper = wrapper
+        self.coordinator = coordinator
         self.key = key
         self._attr_should_poll = False
         self._attr_device_info = {
-            "connections": {(device_registry.CONNECTION_NETWORK_MAC, wrapper.mac)}
+            "connections": {(device_registry.CONNECTION_NETWORK_MAC, coordinator.mac)}
         }
-        self._attr_unique_id = f"{wrapper.mac}-{key}"
-        self._attr_name = get_rpc_entity_name(wrapper.device, key)
+        self._attr_unique_id = f"{coordinator.mac}-{key}"
+        self._attr_name = get_rpc_entity_name(coordinator.device, key)
 
     @property
     def available(self) -> bool:
         """Available."""
-        return self.wrapper.device.connected
+        return self.coordinator.last_update_success
 
     @property
     def status(self) -> dict:
         """Device status by entity key."""
-        return cast(dict, self.wrapper.device.status[self.key])
+        return cast(dict, self.coordinator.device.status[self.key])
 
     async def async_added_to_hass(self) -> None:
         """When entity is added to HASS."""
-        self.async_on_remove(self.wrapper.async_add_listener(self._update_callback))
+        self.async_on_remove(self.coordinator.async_add_listener(self._update_callback))
 
     async def async_update(self) -> None:
         """Update entity with latest info."""
-        await self.wrapper.async_request_refresh()
+        await self.coordinator.async_request_refresh()
 
     @callback
     def _update_callback(self) -> None:
@@ -381,18 +423,18 @@ class ShellyRpcEntity(entity.Entity):
             params,
         )
         try:
-            async with async_timeout.timeout(AIOSHELLY_DEVICE_TIMEOUT_SEC):
-                return await self.wrapper.device.call_rpc(method, params)
-        except asyncio.TimeoutError as err:
-            LOGGER.error(
-                "Call RPC for entity %s failed, method: %s, params: %s, error: %s",
-                self.name,
-                method,
-                params,
-                repr(err),
-            )
-            self.wrapper.last_update_success = False
-            return None
+            return await self.coordinator.device.call_rpc(method, params)
+        except DeviceConnectionError as err:
+            self.coordinator.last_update_success = False
+            raise HomeAssistantError(
+                f"Call RPC for {self.name} connection error, method: {method}, params: {params}, error: {repr(err)}"
+            ) from err
+        except RpcCallError as err:
+            raise HomeAssistantError(
+                f"Call RPC for {self.name} request error, method: {method}, params: {params}, error: {repr(err)}"
+            ) from err
+        except InvalidAuthError:
+            self.coordinator.entry.async_start_reauth(self.hass)
 
 
 class ShellyBlockAttributeEntity(ShellyBlockEntity, entity.Entity):
@@ -402,18 +444,20 @@ class ShellyBlockAttributeEntity(ShellyBlockEntity, entity.Entity):
 
     def __init__(
         self,
-        wrapper: BlockDeviceWrapper,
+        coordinator: ShellyBlockCoordinator,
         block: Block,
         attribute: str,
         description: BlockEntityDescription,
     ) -> None:
         """Initialize sensor."""
-        super().__init__(wrapper, block)
+        super().__init__(coordinator, block)
         self.attribute = attribute
         self.entity_description = description
 
         self._attr_unique_id: str = f"{super().unique_id}-{self.attribute}"
-        self._attr_name = get_block_entity_name(wrapper.device, block, description.name)
+        self._attr_name = get_block_entity_name(
+            coordinator.device, block, description.name
+        )
 
     @property
     def attribute_value(self) -> StateType:
@@ -442,40 +486,42 @@ class ShellyBlockAttributeEntity(ShellyBlockEntity, entity.Entity):
         return self.entity_description.extra_state_attributes(self.block)
 
 
-class ShellyRestAttributeEntity(update_coordinator.CoordinatorEntity):
+class ShellyRestAttributeEntity(CoordinatorEntity[ShellyBlockCoordinator]):
     """Class to load info from REST."""
 
     entity_description: RestEntityDescription
 
     def __init__(
         self,
-        wrapper: BlockDeviceWrapper,
+        coordinator: ShellyBlockCoordinator,
         attribute: str,
         description: RestEntityDescription,
     ) -> None:
         """Initialize sensor."""
-        super().__init__(wrapper)
-        self.wrapper = wrapper
+        super().__init__(coordinator)
+        self.block_coordinator = coordinator
         self.attribute = attribute
         self.entity_description = description
-        self._attr_name = get_block_entity_name(wrapper.device, None, description.name)
-        self._attr_unique_id = f"{wrapper.mac}-{attribute}"
+        self._attr_name = get_block_entity_name(
+            coordinator.device, None, description.name
+        )
+        self._attr_unique_id = f"{coordinator.mac}-{attribute}"
         self._attr_device_info = DeviceInfo(
-            connections={(device_registry.CONNECTION_NETWORK_MAC, wrapper.mac)}
+            connections={(device_registry.CONNECTION_NETWORK_MAC, coordinator.mac)}
         )
         self._last_value = None
 
     @property
     def available(self) -> bool:
         """Available."""
-        return self.wrapper.last_update_success
+        return self.block_coordinator.last_update_success
 
     @property
     def attribute_value(self) -> StateType:
         """Value of sensor."""
         if callable(self.entity_description.value):
             self._last_value = self.entity_description.value(
-                self.wrapper.device.status, self._last_value
+                self.block_coordinator.device.status, self._last_value
             )
         return self._last_value
 
@@ -486,7 +532,7 @@ class ShellyRestAttributeEntity(update_coordinator.CoordinatorEntity):
             return None
 
         return self.entity_description.extra_state_attributes(
-            self.wrapper.device.status
+            self.block_coordinator.device.status
         )
 
 
@@ -497,18 +543,18 @@ class ShellyRpcAttributeEntity(ShellyRpcEntity, entity.Entity):
 
     def __init__(
         self,
-        wrapper: RpcDeviceWrapper,
+        coordinator: ShellyRpcCoordinator,
         key: str,
         attribute: str,
         description: RpcEntityDescription,
     ) -> None:
         """Initialize sensor."""
-        super().__init__(wrapper, key)
+        super().__init__(coordinator, key)
         self.attribute = attribute
         self.entity_description = description
 
         self._attr_unique_id = f"{super().unique_id}-{attribute}"
-        self._attr_name = get_rpc_entity_name(wrapper.device, key, description.name)
+        self._attr_name = get_rpc_entity_name(coordinator.device, key, description.name)
         self._last_value = None
 
     @property
@@ -516,13 +562,13 @@ class ShellyRpcAttributeEntity(ShellyRpcEntity, entity.Entity):
         """Value of sensor."""
         if callable(self.entity_description.value):
             self._last_value = self.entity_description.value(
-                self.wrapper.device.status[self.key].get(
+                self.coordinator.device.status[self.key].get(
                     self.entity_description.sub_key
                 ),
                 self._last_value,
             )
         else:
-            self._last_value = self.wrapper.device.status[self.key][
+            self._last_value = self.coordinator.device.status[self.key][
                 self.entity_description.sub_key
             ]
 
@@ -537,7 +583,7 @@ class ShellyRpcAttributeEntity(ShellyRpcEntity, entity.Entity):
             return available
 
         return self.entity_description.available(
-            self.wrapper.device.status[self.key][self.entity_description.sub_key]
+            self.coordinator.device.status[self.key][self.entity_description.sub_key]
         )
 
     @property
@@ -546,11 +592,11 @@ class ShellyRpcAttributeEntity(ShellyRpcEntity, entity.Entity):
         if self.entity_description.extra_state_attributes is None:
             return None
 
-        assert self.wrapper.device.shelly
+        assert self.coordinator.device.shelly
 
         return self.entity_description.extra_state_attributes(
-            self.wrapper.device.status[self.key][self.entity_description.sub_key],
-            self.wrapper.device.shelly,
+            self.coordinator.device.status[self.key][self.entity_description.sub_key],
+            self.coordinator.device.shelly,
         )
 
 
@@ -560,30 +606,33 @@ class ShellySleepingBlockAttributeEntity(ShellyBlockAttributeEntity, RestoreEnti
     # pylint: disable=super-init-not-called
     def __init__(
         self,
-        wrapper: BlockDeviceWrapper,
+        coordinator: ShellyBlockCoordinator,
         block: Block | None,
         attribute: str,
         description: BlockEntityDescription,
-        entry: entity_registry.RegistryEntry | None = None,
+        entry: RegistryEntry | None = None,
         sensors: Mapping[tuple[str, str], BlockEntityDescription] | None = None,
     ) -> None:
         """Initialize the sleeping sensor."""
         self.sensors = sensors
         self.last_state: StateType = None
-        self.wrapper = wrapper
+        self.last_unit: str | None = None
+        self.coordinator = coordinator
         self.attribute = attribute
         self.block: Block | None = block  # type: ignore[assignment]
         self.entity_description = description
 
         self._attr_should_poll = False
         self._attr_device_info = DeviceInfo(
-            connections={(device_registry.CONNECTION_NETWORK_MAC, wrapper.mac)}
+            connections={(device_registry.CONNECTION_NETWORK_MAC, coordinator.mac)}
         )
 
         if block is not None:
-            self._attr_unique_id = f"{self.wrapper.mac}-{block.description}-{attribute}"
+            self._attr_unique_id = (
+                f"{self.coordinator.mac}-{block.description}-{attribute}"
+            )
             self._attr_name = get_block_entity_name(
-                self.wrapper.device, block, self.entity_description.name
+                self.coordinator.device, block, self.entity_description.name
             )
         elif entry is not None:
             self._attr_unique_id = entry.unique_id
@@ -597,13 +646,14 @@ class ShellySleepingBlockAttributeEntity(ShellyBlockAttributeEntity, RestoreEnti
 
         if last_state is not None:
             self.last_state = last_state.state
+            self.last_unit = last_state.attributes.get(ATTR_UNIT_OF_MEASUREMENT)
 
     @callback
     def _update_callback(self) -> None:
         """Handle device update."""
         if (
             self.block is not None
-            or not self.wrapper.device.initialized
+            or not self.coordinator.device.initialized
             or self.sensors is None
         ):
             super()._update_callback()
@@ -611,9 +661,9 @@ class ShellySleepingBlockAttributeEntity(ShellyBlockAttributeEntity, RestoreEnti
 
         _, entity_block, entity_sensor = self._attr_unique_id.split("-")
 
-        assert self.wrapper.device.blocks
+        assert self.coordinator.device.blocks
 
-        for block in self.wrapper.device.blocks:
+        for block in self.coordinator.device.blocks:
             if block.description != entity_block:
                 continue
 
@@ -631,3 +681,52 @@ class ShellySleepingBlockAttributeEntity(ShellyBlockAttributeEntity, RestoreEnti
                 LOGGER.debug("Entity %s attached to block", self.name)
                 super()._update_callback()
                 return
+
+
+class ShellySleepingRpcAttributeEntity(ShellyRpcAttributeEntity, RestoreEntity):
+    """Helper class to represent a sleeping rpc attribute."""
+
+    entity_description: RpcEntityDescription
+
+    # pylint: disable=super-init-not-called
+    def __init__(
+        self,
+        coordinator: ShellyRpcCoordinator,
+        key: str,
+        attribute: str,
+        description: RpcEntityDescription,
+        entry: RegistryEntry | None = None,
+    ) -> None:
+        """Initialize the sleeping sensor."""
+        self.last_state: StateType = None
+        self.last_unit: str | None = None
+        self.coordinator = coordinator
+        self.key = key
+        self.attribute = attribute
+        self.entity_description = description
+
+        self._attr_should_poll = False
+        self._attr_device_info = DeviceInfo(
+            connections={(device_registry.CONNECTION_NETWORK_MAC, coordinator.mac)}
+        )
+        self._attr_unique_id = (
+            self._attr_unique_id
+        ) = f"{coordinator.mac}-{key}-{attribute}"
+        self._last_value = None
+
+        if coordinator.device.initialized:
+            self._attr_name = get_rpc_entity_name(
+                coordinator.device, key, description.name
+            )
+        elif entry is not None:
+            self._attr_name = cast(str, entry.original_name)
+
+    async def async_added_to_hass(self) -> None:
+        """Handle entity which will be added."""
+        await super().async_added_to_hass()
+
+        last_state = await self.async_get_last_state()
+
+        if last_state is not None:
+            self.last_state = last_state.state
+            self.last_unit = last_state.attributes.get(ATTR_UNIT_OF_MEASUREMENT)
