@@ -25,6 +25,7 @@ from homeassistant.const import (
     CONF_ENTITY_ID,
     CONF_NAME,
     CONF_UNIQUE_ID,
+    PERCENTAGE,
     STATE_UNAVAILABLE,
     STATE_UNKNOWN,
 )
@@ -33,10 +34,11 @@ from homeassistant.core import (
     Event,
     HomeAssistant,
     State,
+    async_get_hass,
     callback,
     split_entity_id,
 )
-from homeassistant.helpers import config_validation as cv
+from homeassistant.helpers import config_validation as cv, issue_registry
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.event import (
     async_track_point_in_utc_time,
@@ -78,20 +80,14 @@ STAT_MEDIAN = "median"
 STAT_NOISINESS = "noisiness"
 STAT_QUANTILES = "quantiles"
 STAT_STANDARD_DEVIATION = "standard_deviation"
+STAT_SUM = "sum"
+STAT_SUM_DIFFERENCES = "sum_differences"
+STAT_SUM_DIFFERENCES_NONNEGATIVE = "sum_differences_nonnegative"
 STAT_TOTAL = "total"
 STAT_VALUE_MAX = "value_max"
 STAT_VALUE_MIN = "value_min"
 STAT_VARIANCE = "variance"
 
-DEPRECATION_WARNING_CHARACTERISTIC = (
-    "The configuration parameter 'state_characteristic' will become "
-    "mandatory in a future release of the statistics integration. "
-    "Please add 'state_characteristic: %s' to the configuration of "
-    "sensor '%s' to keep the current behavior. Read the documentation "
-    "for further details: "
-    "https://www.home-assistant.io/integrations/statistics/"
-)
-
 # Statistics supported by a sensor source (numeric)
 STATS_NUMERIC_SUPPORT = {
     STAT_AVERAGE_LINEAR,
@@ -113,6 +109,9 @@ STATS_NUMERIC_SUPPORT = {
     STAT_NOISINESS,
     STAT_QUANTILES,
     STAT_STANDARD_DEVIATION,
+    STAT_SUM,
+    STAT_SUM_DIFFERENCES,
+    STAT_SUM_DIFFERENCES_NONNEGATIVE,
     STAT_TOTAL,
     STAT_VALUE_MAX,
     STAT_VALUE_MIN,
@@ -159,6 +158,9 @@ STAT_NUMERIC_RETAIN_UNIT = {
     STAT_MEDIAN,
     STAT_NOISINESS,
     STAT_STANDARD_DEVIATION,
+    STAT_SUM,
+    STAT_SUM_DIFFERENCES,
+    STAT_SUM_DIFFERENCES_NONNEGATIVE,
     STAT_TOTAL,
     STAT_VALUE_MAX,
     STAT_VALUE_MIN,
@@ -179,7 +181,6 @@ CONF_QUANTILE_INTERVALS = "quantile_intervals"
 CONF_QUANTILE_METHOD = "quantile_method"
 
 DEFAULT_NAME = "Stats"
-DEFAULT_BUFFER_SIZE = 20
 DEFAULT_PRECISION = 2
 DEFAULT_QUANTILE_INTERVALS = 4
 DEFAULT_QUANTILE_METHOD = "exclusive"
@@ -192,10 +193,19 @@ def valid_state_characteristic_configuration(config: dict[str, Any]) -> dict[str
 
     if config.get(CONF_STATE_CHARACTERISTIC) is None:
         config[CONF_STATE_CHARACTERISTIC] = STAT_COUNT if is_binary else STAT_MEAN
-        _LOGGER.warning(
-            DEPRECATION_WARNING_CHARACTERISTIC,
-            config[CONF_STATE_CHARACTERISTIC],
-            config[CONF_NAME],
+        issue_registry.async_create_issue(
+            hass=async_get_hass(),
+            domain=DOMAIN,
+            issue_id=f"{config[CONF_ENTITY_ID]}_default_characteristic",
+            breaks_in_ha_version="2022.12.0",
+            is_fixable=False,
+            severity=issue_registry.IssueSeverity.WARNING,
+            translation_key="deprecation_warning_characteristic",
+            translation_placeholders={
+                "entity": config[CONF_NAME],
+                "characteristic": config[CONF_STATE_CHARACTERISTIC],
+            },
+            learn_more_url="https://github.com/home-assistant/core/pull/60402",
         )
 
     characteristic = cast(str, config[CONF_STATE_CHARACTERISTIC])
@@ -210,15 +220,32 @@ def valid_state_characteristic_configuration(config: dict[str, Any]) -> dict[str
     return config
 
 
+def valid_boundary_configuration(config: dict[str, Any]) -> dict[str, Any]:
+    """Validate that sampling_size, max_age, or both are provided."""
+
+    if config.get(CONF_SAMPLES_MAX_BUFFER_SIZE) is None:
+        config[CONF_SAMPLES_MAX_BUFFER_SIZE] = 20
+        issue_registry.async_create_issue(
+            hass=async_get_hass(),
+            domain=DOMAIN,
+            issue_id=f"{config[CONF_ENTITY_ID]}_invalid_boundary_config",
+            breaks_in_ha_version="2022.12.0",
+            is_fixable=False,
+            severity=issue_registry.IssueSeverity.WARNING,
+            translation_key="deprecation_warning_size",
+            translation_placeholders={"entity": config[CONF_NAME]},
+            learn_more_url="https://github.com/home-assistant/core/pull/69700",
+        )
+    return config
+
+
 _PLATFORM_SCHEMA_BASE = PLATFORM_SCHEMA.extend(
     {
         vol.Required(CONF_ENTITY_ID): cv.entity_id,
         vol.Optional(CONF_NAME, default=DEFAULT_NAME): cv.string,
         vol.Optional(CONF_UNIQUE_ID): cv.string,
         vol.Optional(CONF_STATE_CHARACTERISTIC): cv.string,
-        vol.Optional(
-            CONF_SAMPLES_MAX_BUFFER_SIZE, default=DEFAULT_BUFFER_SIZE
-        ): vol.All(vol.Coerce(int), vol.Range(min=1)),
+        vol.Optional(CONF_SAMPLES_MAX_BUFFER_SIZE): vol.Coerce(int),
         vol.Optional(CONF_MAX_AGE): cv.time_period,
         vol.Optional(CONF_PRECISION, default=DEFAULT_PRECISION): vol.Coerce(int),
         vol.Optional(
@@ -232,6 +259,7 @@ _PLATFORM_SCHEMA_BASE = PLATFORM_SCHEMA.extend(
 PLATFORM_SCHEMA = vol.All(
     _PLATFORM_SCHEMA_BASE,
     valid_state_characteristic_configuration,
+    valid_boundary_configuration,
 )
 
 
@@ -377,7 +405,7 @@ class StatisticsSensor(SensorEntity):
         base_unit: str | None = new_state.attributes.get(ATTR_UNIT_OF_MEASUREMENT)
         unit: str | None
         if self.is_binary and self._state_characteristic in STAT_BINARY_PERCENTAGE:
-            unit = "%"
+            unit = PERCENTAGE
         elif not base_unit:
             unit = None
         elif self._state_characteristic in STAT_NUMERIC_RETAIN_UNIT:
@@ -669,10 +697,7 @@ class StatisticsSensor(SensorEntity):
 
     def _stat_noisiness(self) -> StateType:
         if len(self.states) >= 2:
-            diff_sum = sum(
-                abs(j - i) for i, j in zip(list(self.states), list(self.states)[1:])
-            )
-            return diff_sum / (len(self.states) - 1)
+            return cast(float, self._stat_sum_differences()) / (len(self.states) - 1)
         return None
 
     def _stat_quantiles(self) -> StateType:
@@ -694,11 +719,31 @@ class StatisticsSensor(SensorEntity):
             return statistics.stdev(self.states)
         return None
 
-    def _stat_total(self) -> StateType:
+    def _stat_sum(self) -> StateType:
         if len(self.states) > 0:
             return sum(self.states)
         return None
 
+    def _stat_sum_differences(self) -> StateType:
+        if len(self.states) >= 2:
+            diff_sum = sum(
+                abs(j - i) for i, j in zip(list(self.states), list(self.states)[1:])
+            )
+            return diff_sum
+        return None
+
+    def _stat_sum_differences_nonnegative(self) -> StateType:
+        if len(self.states) >= 2:
+            diff_sum_nn = sum(
+                (j - i if j >= i else j - 0)
+                for i, j in zip(list(self.states), list(self.states)[1:])
+            )
+            return diff_sum_nn
+        return None
+
+    def _stat_total(self) -> StateType:
+        return self._stat_sum()
+
     def _stat_value_max(self) -> StateType:
         if len(self.states) > 0:
             return max(self.states)
